AuthDialog

Struct AuthDialog 

pub struct AuthDialog {
    stack: TemplateChild<Stack>,
    session: WeakRef<Session>,
    is_presented: Cell<bool>,
    state: RefCell<Option<AuthState>>,
    current_page: RefCell<Option<Widget>>,
    notifier: OnceCell<OneshotNotifier<Option<()>>>,
    abort_handle: RefCell<Option<AbortHandle>>,
}

Fields

stack: TemplateChild<Stack>session: WeakRef<Session>

The parent session.

is_presented: Cell<bool>

Whether this dialog is presented.

state: RefCell<Option<AuthState>>

The current state of the authentication.

None means that the authentication has not started yet.

current_page: RefCell<Option<Widget>>

The page for the current stage.

notifier: OnceCell<OneshotNotifier<Option<()>>>

The notifier to signal to perform the current stage.

abort_handle: RefCell<Option<AbortHandle>>

The handle to abort the current future.

Implementations

Source

impl AuthDialog

fn register_type()

Registers the type only once.

Source

impl AuthDialog

pub fn downgrade(&self) -> <Self as Downgrade>::Weak

Source

impl AuthDialog

fn notifier(&self) -> &OneshotNotifier<Option<()>>

The notifier to signal to perform the current stage.

pub(super) async fn authenticate<Response, Fut, FN>( &self, parent: &Widget, callback: FN, ) -> Result<Response, AuthError>
where Response: Send + 'static, Fut: Future<Output = Result<Response, Error>> + Send + 'static, FN: Fn(Client, Option<AuthData>) -> Fut + Send + Sync + 'static + Clone,

Authenticate the user to the server via an interactive authentication flow.

The type of flow and the required stages are negotiated during the authentication. Returns the last server response on success.

pub(super) async fn reset_cross_signing( &self, parent: &Widget, ) -> Result<(), AuthError>

Reset the cross-signing keys while handling the interactive authentication flow.

The type of flow and the required stages are negotiated during the authentication.

Note that due to the implementation of the underlying SDK API, this will not work if there are several stages in the flow.

Returns the last server response on success.

async fn await_tokio_task<Response>( &self, handle: JoinHandle<Result<Response, Error>>, ) -> Result<Response, AuthError>
where Response: Send + 'static,

Await the given tokio task, handling if it is aborted.

async fn perform_uiaa<Response, Fut, FN>( &self, uiaa_info: UiaaInfo, parent: &Widget, callback: FN, ) -> Result<Response, AuthError>
where Response: Send + 'static, Fut: Future<Output = Result<Response, Error>> + Send + 'static, FN: Fn(AuthData) -> Fut + Send + Sync + 'static + Clone,

Perform UIAA for the given callback, starting with the given UIAA info.

async fn perform_next_stage( &self, uiaa_info: &UiaaInfo, parent: &Widget, ) -> Result<AuthData, AuthError>

Perform the preferred next stage in the given UIAA info.

Stages that are actually supported are preferred. If no stages are supported, we use the web-based fallback.

When this function returns, the next stage is ready to be performed.

fn retry_current_stage(&self, stage: &AuthType, uiaa_info: &UiaaInfo)

fn show_page(&self, page: Widget, default_widget: &Widget, parent: &Widget)

Show the given page.

async fn page(&self, state: &AuthState) -> Result<(Widget, Widget), AuthError>

Get the page for the given state.

Returns a (page, default_widget) tuple.

async fn fallback_url(&self, state: &AuthState) -> Result<String, AuthError>

Get the fallback URL for the given state.

fn current_stage_auth_data(&self) -> Result<AuthData, AuthError>

Get the authentication data for the current stage.

fn close(&self)